OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} is beschikbaar. Meer informatie over het bijwerken.",
    "Channel updated" : "Kanaal bijgewerkt",
    "Web updater is disabled" : "Web-updater is uitgeschakeld",
    "Update notifications" : "Bijwerkmeldingen",
    "The update server could not be reached since %d days to check for new updates." : "De updateserver kon sinds %d dagen niet meer worden bereikt om op updates te controleren.",
    "Please check the Nextcloud and server log files for errors." : "Controleer de Nextcloud- en serverlogbestanden op fouten.",
    "Update to %1$s is available." : "Update naar %1$s is beschikbaar.",
    "Update for {app} to version %s is available." : "Update voor {app} naar versie %s is beschikbaar.",
    "Update notification" : "Bijwerkmelding",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Toont updatemeldingen voor Nextcloud en zorgt voor SSO voor de updater.",
    "Update" : "Update",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "De versie die je gebruikt, wordt niet langer ondersteund. Zorg ervoor om zo snel mogelijk bij te werken naar een ondersteunde versie.",
    "Apps missing compatible version" : "Apps zonder compatibele versie",
    "View in store" : "Bekijk in winkel",
    "Apps with compatible version" : "Apps met compatibele versie",
    "Open updater" : "Open updater",
    "Download now" : "Download nu",
    "What's new?" : "Wat is nieuw?",
    "View changelog" : "Bekijk wijzigingenoverzicht",
    "The update check is not yet finished. Please refresh the page." : "De updatecontrole is niet afgerond. Ververs de pagina.",
    "Your version is up to date." : "Je versie is up-to-date.",
    "A non-default update server is in use to be checked for updates:" : "Een niet-standaard updateserver is in gebruik om te worden gecontroleerd op updates:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Je kan altijd naar een nieuwere versie, maar je kan nooit terug naar een oudere stabielere versie.",
    "Notify members of the following groups about available updates:" : "Geef een melding over beschikbare updates aan leden van de volgende groepen:",
    "Only notifications for app updates are available." : "Er zijn alleen meldingen voor apps beschikbaar.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Het geselecteerde updatekanaal maakt overbodig om serverspecifieke meldingen apart te genereren.",
    "The selected update channel does not support updates of the server." : "Het geselecteerde updatekanaal ondersteunt geen updates voor de server.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Er is een nieuwe versie beschikbaar: <strong>{newVersionString}</strong>",
    "Checking apps for compatible versions" : "Apps controleren op compatibele versies.",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Zorg ervoor dat je in config.php <samp>appstoreenabled</samp> niet op 'false' zet.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Kan niet verbinden met de App Store of er zijn geen updates teruggegeven. Zoek handmatig naar updates of verifieer dat je server internettoegang heeft en kan verbinden met de App Store.",
    "Enterprise" : "Zakelijk",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Voor zakelijk gebruik. Biedt altijd het laatste patch level, maar zal niet meteen naar de laatste hoofdrelease bijwerken. Die update vindt pas plaats nadat Nextcloud GmbH aanvullende hardening en tests voor grootschalige en bedrijfskritische installaties heeft uitgevoerd. Dit kanaal is alleen beschikbaar voor klanten en levert het Nextcloud Enterprise pakket.",
    "Stable" : "Stabiel",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "De meest recente stabiele versie. Het is geschikt voor normaal gebruik en werkt altijd bij naar de laatste hoofdversie.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Een vroeg vrijgegeven versie, alleen bedoeld om nieuwe functies te testen. Niet voor productieomgevingen.",
    "Please use the command line updater to update." : "Gebruik de commandoregel updater, om bij te werken.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Je kunt het updatekanaal hieronder wijzigen, wat ook van invloed is op de beheerpagina van apps. bijv. nadat je bent overgeschakeld naar het bètakanaal, worden bèta-app-updates aangeboden op de beheerpagina voor apps.",
    "Update channel:" : "Bijwerkkanaal:",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Let op dat na een nieuwe release de update pas verschijnt na de eerste secundaire release of later. We introduceren nieuwe versies verspreid over de tijd voor onze gebruikers en slaan soms een versie over wanneer er problemen worden gevonden. Lees meer over updates en releasekanalen op {link}",
    "Checked on {lastCheckedDate}" : "Gecontroleerd op {lastCheckedDate}"
},
"nplurals=2; plural=(n != 1);");
